@@ -58,7 +58,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 
 );
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 # -----------------------------------------------
 
@@ -201,9 +201,7 @@ sub generate_parent_module
 
 sub new
 {
-	my($caller, %arg)	= @_;
-	my($caller_is_obj)	= ref($caller);
-	my($class)			= $caller_is_obj || $caller;
+	my($class, %arg)	= @_;
 	my($self)			= bless({}, $class);
 
 	for my $attr_name ($self -> _standard_keys() )
@@ -214,10 +212,6 @@ sub new
 		{
 			$$self{$attr_name} = $arg{$arg_name};
 		}
-		elsif ($caller_is_obj)
-		{
-			$$self{$attr_name} = $$caller{$attr_name};
-		}
 		else
 		{
 			$$self{$attr_name} = $self -> _default_for($attr_name);
